@@ -1228,13 +1228,12 @@ camel_message_info_get_dirty (const CamelMessageInfo *mi)
  * @dirty: a dirty state to set
  *
  * Marks the @mi as dirty, which means a save to the local summary
- * is required. In case the @dirty is %TRUE and the @mi is not aborting notifications,
- * the 'dirty-stamp' changes too.
+ * is required.
  *
  * Since: 3.24
  **/
 void
-camel_message_info_set_dirty (const CamelMessageInfo *mi,
+camel_message_info_set_dirty (CamelMessageInfo *mi,
 			      gboolean dirty)
 {
 	gboolean changed, abort_notifications;
@@ -1292,7 +1291,7 @@ camel_message_info_get_folder_flagged (const CamelMessageInfo *mi)
 /**
  * camel_message_info_set_folder_flagged:
  * @mi: a #CamelMessageInfo
- * folder_flagged: a value to set to
+ * @folder_flagged: a value to set to
  *
  * Changes the folder-flagged flag to the @folder_flagged value. See
  * camel_message_info_get_folder_flagged() for more information about
@@ -1881,6 +1880,7 @@ camel_message_info_get_user_tag (const CamelMessageInfo *mi,
 /**
  * camel_message_info_dup_user_tag:
  * @mi: a #CamelMessageInfo
+ * @name: user tag name
  *
  * Returns: (transfer full) (nullable): Value of the user tag as newly allocated
  *   string, or %NULL when it is not set. Free it with g_free() when no longer needed.
